export declare class Emitter {
    private eventCallbacks;
    /**
     * Register an event type by name. This method is called when the 'on' method is called if an event of that type has
     * not been registered yet.
     * @param eventName
     */
    register(eventName: string): void;
    /**
     * Add an event callback with optional context
     * @param eventName
     * @param callback
     * @param context
     */
    on(eventName: string, callback: Function, context?: object): void;
    /**
     * Remove an event callback by reference
     * @param eventName
     * @param [callback]
     * @param [force=false]
     */
    off(eventName: string): void;
    off(eventName: string, callback: Function): void;
    off(eventName: string, callback: Function, force: boolean): void;
    /**
     * Dispatch an event with eventName using the 'call' method
     * @param eventName
     * @param args
     */
    dispatch(eventName: string, ...args: any[]): void;
    /**
     * Dispatch an event with eventName using the 'apply' method
     * @param eventName
     * @param args
     */
    dispatchApply(eventName: string, args?: any[]): void;
    /**
     * Alias for the dispatch method
     * @param eventName
     * @param args
     */
    emit(eventName: string, ...args: any[]): void;
    /**
     * Remove all listeners from this instance
     */
    removeListeners(): void;
    /**
     * Getter to check if any listeners are present on this emitter
     */
    hasListeners(): boolean;
}
