export declare type Comparator<T> = (a: T, b: T) => boolean;
/**
 * Returns the intersection between to sets
 * @param setA
 * @param setB
 * @param comparator
 */
export declare function intersection<T>(setA: T[], setB: T[], comparator?: Comparator<T>): T[];
/**
 * Returns the union of two sets
 * @param setA
 * @param setB
 * @param comparator
 */
export declare function union<T>(setA: T[], setB: T[], comparator?: Comparator<T>): T[];
/**
 * Returns the left difference between two sets. This will keep values that exist in setA which do not exist in setB
 * @param setA
 * @param setB
 * @param comparator
 */
export declare function difference<T>(setA: T[], setB: T[], comparator?: Comparator<T>): T[];
/**
 * Returns the right difference between two sets. This will keep values that exist in setB which do not exist in setA
 * @param setA
 * @param setB
 * @param comparator
 */
export declare function rightDifference<T>(setA: T[], setB: T[], comparator?: Comparator<T>): T[];
/**
 * Will return the complete set of values that exist in either setA or setB, but not both.
 * @param setA
 * @param setB
 * @param comparator
 */
export declare function exclusiveOr<T>(setA: T[], setB: T[], comparator?: Comparator<T>): T[];
