"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function defaultComparator(a, b) {
    return a === b;
}
/**
 * Returns the intersection between to sets
 * @param setA
 * @param setB
 * @param comparator
 */
function intersection(setA, setB, comparator = defaultComparator) {
    return setA.filter(a => setB.find(b => comparator(a, b)));
}
exports.intersection = intersection;
/**
 * Returns the union of two sets
 * @param setA
 * @param setB
 * @param comparator
 */
function union(setA, setB, comparator = defaultComparator) {
    return setA.filter(a => !setB.find(b => comparator(a, b))).concat(setB);
}
exports.union = union;
/**
 * Returns the left difference between two sets. This will keep values that exist in setA which do not exist in setB
 * @param setA
 * @param setB
 * @param comparator
 */
function difference(setA, setB, comparator = defaultComparator) {
    return setA.filter(a => !setB.find(b => comparator(a, b)));
}
exports.difference = difference;
/**
 * Returns the right difference between two sets. This will keep values that exist in setB which do not exist in setA
 * @param setA
 * @param setB
 * @param comparator
 */
function rightDifference(setA, setB, comparator = defaultComparator) {
    return difference(setB, setA, comparator);
}
exports.rightDifference = rightDifference;
/**
 * Will return the complete set of values that exist in either setA or setB, but not both.
 * @param setA
 * @param setB
 * @param comparator
 */
function exclusiveOr(setA, setB, comparator = defaultComparator) {
    return difference(setA, setB, comparator).concat(rightDifference(setA, setB, comparator));
}
exports.exclusiveOr = exclusiveOr;
