"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * An asynchronous wait function. Just useful for throttling purposes.
 * @param ms  - The number of milliseconds to wait before resolving the promise
 */
function wait(ms) {
    return new Promise(resolve => {
        setTimeout(resolve, ms);
    });
}
exports.wait = wait;
/**
 * A shared throttle. Safe to be used by multiple asynchronous requests at the same time.
 * @param freq - The number of milliseconds between resolution of this function
 */
function throttler(freq) {
    const Mutex = require('async-mutex').Mutex;
    const mutex = new Mutex();
    return function () {
        return __awaiter(this, void 0, void 0, function* () {
            const release = yield mutex.acquire();
            try {
                yield wait(freq);
            }
            finally {
                release();
            }
        });
    };
}
exports.throttler = throttler;
